package de.intevation.mxd.reader;

import org.apache.log4j.Logger;

import com.esri.arcgis.display.ISymbol;
import com.esri.arcgis.display.IMarkerSymbol;
import com.esri.arcgis.display.ArrowMarkerSymbol;
import com.esri.arcgis.display.IColor;

import org.w3c.dom.Element;

/**
 * Reads arrow marker symbol information.
 *
 * @author <a href="mailto:raimund.renkert@intevation.de">Raimund Renkert</a>
 */
public class ArrowMarkerSymbolReader
extends AbstractSymbolReader {

    /**
     * The logger.
     */
    private static final Logger logger =
        Logger.getLogger(ArrowMarkerSymbolReader.class);

    /**
     * Private member.
     */
    private ArrowMarkerSymbol symbol;

    public ArrowMarkerSymbolReader(ISymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof ArrowMarkerSymbol) {
            this.symbol = (ArrowMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a ArrowMarkerSymbol!");
        }
    }

    public ArrowMarkerSymbolReader(IMarkerSymbol symbol)
    throws Exception {
        logger.debug("contructor()");
        if(symbol instanceof ArrowMarkerSymbol) {
            this.symbol = (ArrowMarkerSymbol)symbol;
        }
        else {
            throw new Exception("Not a ArrowMarkerSymbol!");
        }
    }

    /**
     * Reads the symbol attributes.
     *
     * @return The XML node.
     */
    public Element read()
    throws Exception {
        logger.debug("read()");
        Element symbolElement = util.addSymbol(parent);

        IColor c = symbol.getColor();
        symbolElement.setAttribute(
            "angle",
            String.valueOf(symbol.getAngle()));
        symbolElement.setAttribute(
            "size",
            String.valueOf(symbol.getSize()));
        symbolElement.setAttribute(
            "x_offset",
            String.valueOf(symbol.getXOffset()));
        symbolElement.setAttribute(
            "y_offset",
            String.valueOf(symbol.getYOffset()));
        symbolElement.setAttribute(
            "color",
            String.valueOf(c.getRGB()));
        symbolElement.setAttribute(
            "tranparency",
            String.valueOf(c.getTransparency()));
        symbolElement.setAttribute(
            "name",
            symbol.getNameString());
        symbolElement.setAttribute(
            "length",
            String.valueOf(symbol.getLength()));
        symbolElement.setAttribute(
            "width",
            String.valueOf(symbol.getWidth()));
        symbolElement.setAttribute("style", "arrow");
        return symbolElement;
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
